@@ -6,10 +6,13 @@ import click
 from dotnetcore2 import runtime
 runtime.version = ("18", "10", "0")
 
-from energinetml.settings import PACKAGE_VERSION
+from energinetml.settings import PACKAGE_VERSION  # noqa: E402
 
-from .project import project_group
-from .model import model_group
+from .project import project_group  # noqa: E402
+from .model import model_group  # noqa: E402
+from .cluster import cluster_group  # noqa: E402
+from .webapp import webapp_group  # noqa: E402
+from .infrastructure import infrastructure_group  # noqa: E402
 
 
 @click.command()
@@ -22,9 +25,15 @@ def version():
 
 @click.group()
 def main():
+    """
+    Click main entrypoint.
+    """
     pass
 
 
 main.add_command(project_group, 'project')
 main.add_command(model_group, 'model')
+main.add_command(cluster_group, 'cluster')
+main.add_command(webapp_group, 'webapp')
+main.add_command(infrastructure_group, 'infrastructure')
 main.add_command(version)
