@@ -11,7 +11,9 @@ from energinetml.cli.utils import discover_model, discover_trained_model
               help='Host to serve on (default: 127.0.0.1)')
 @click.option('--port', default=8080, type=int,
               help='Port to serve on (default: 8080)')
-@click.option('--model-version', 'model_version', default=None, type=str,
+@click.option('--model-version', 'model_version',
+              required=False, type=str,
+              default='Unspecified',
               help='Model version (used for logging)')
 def serve(host, port, model, trained_model, model_version):
     """
